KGetUriRequest<TDecoded> class
- Inheritance
-
- Object
- KUriRequest<
TDecoded> - KGetUriRequest
- Available extensions
Constructors
-
KGetUriRequest(KRestApi _api, {required Uri uri, bool usePrimary = true, Options? options, CancelToken? cancelToken, void onReceiveProgress(int, int)?, DecodedCallback<
TDecoded> ? decoder, LogOptions? logOptions, ErrorOverrideCallback? errorOverride})
Properties
- cancelToken → CancelToken?
-
finalinherited
- data → Object?
-
finalinherited
-
decoder
→ DecodedCallback<
TDecoded> ? -
finalinherited
- errorOverride → ErrorOverrideCallback?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, Object?> ? -
Replaces Options.headers. Omit to keep what's in options.
finalinherited
- logOptions → LogOptions?
-
finalinherited
- method → String
-
no setter
- onReceiveProgress → void Function(int, int)?
-
finalinherited
- options → Options?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri
-
finalinherited
- usePrimary → bool
-
finalinherited
Methods
-
copyWith(
{Uri? uri, bool? usePrimary, Map< String, String> ? headers, Object? data, Options? options, CancelToken? cancelToken, void onReceiveProgress(int, int)?, LogOptions? logOptions, DecodedCallback<TDecoded> ? decoder, ErrorOverrideCallback? errorOverride}) → KGetUriRequest<TDecoded> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
) → Future< TDecoded?> -
Available on KUriRequest<
TDecoded> , provided by the ExtOnRestUriRequest extension -
sendResponse<
Raw> () → Future< KResponse< Raw, TDecoded> > -
Available on KUriRequest<
TDecoded> , provided by the ExtOnRestUriRequest extension -
sendResult(
) → Future< ApiResult< TDecoded?> > -
Available on KUriRequest<
TDecoded> , provided by the ExtOnRestUriRequest extension -
toString(
) → String -
A string representation of this object.
inherited
-
trySend(
) → Future< TDecoded?> -
Available on KUriRequest<
TDecoded> , provided by the ExtOnRestUriRequest extension -
trySendResponse<
Raw> () → Future< KResponse< Raw, TDecoded> > -
Available on KUriRequest<
TDecoded> , provided by the ExtOnRestUriRequest extension -
trySendResult(
) → Future< ApiResult< TDecoded?> > -
Available on KUriRequest<
TDecoded> , provided by the ExtOnRestUriRequest extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited